#-*- coding: utf-8 -*-

#***********************************************
# oct2spec 
#
# oct2spec helps to create a specfile for an octave package
# It works from a package name (from Octave Forge), source file (*.tar.gz) or
# a url (http://...*.tar.gz)
#
# This software has been based on the guidelines for octave packaging
# http://fedoraproject.org/wiki/Packaging/Octave
#
# Based on R2spec, Made the 13th February 2008
# by Pierre-Yves chibon
#
# Copyright (C) 2011 Orion Poplawski <orion@cora.nwra.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#***********************************************

import sys, re, os
import OctPackage

USAGE ="""
This program is designed to create specfile from a source file or a url.
Usage:  oct2spec -u <url> 
        oct2spec -s <source>
        oct2spec -s folder/folder/<source>
        oct2spec -p <name>

You can also use the following options to add the correct Source0 in the spec file:
  --forge              For libraries coming from the source forge Octave Forge project

The source can be in the same directory or in a subdirectory.

The information about the packager:
- Fill /etc/oct2spec.conf 
- Copy and fill /etc/oct2spec to ~/.oct2spec.conf
- Use the option -n/--name and -e/--email to set the corresponding values
"""

#################################################
### main
# Do the job :)
class Oct2spec:
    """ oct2spec class
            Enables to use this code from another script
    """
    
    def __init__(self):
        self.usage = USAGE
        self.todo = True
    
    def main(self, source, url, pkgname, forge, copyFile, name, email, force):
        ''' Performs the work'''
        
        # Return the usage message if no arguments are given
        if(url == None and source == None and pkgname == None):
            sys.exit(self.usage)

        # Return an error message if there is 2 arguments given
        if ([url, source, pkgname].count(None) < 2):
            sys.exit("\n***  Please give only one argument  ***\n")

        package = OctPackage.OctPackage()

        # For a given package name, set the url by looking at the repository
        if (pkgname != None):
            (specurl, url) = package.findSourceOfPackage(pkgname)
            if specurl is None:
                sys.exit("Could not find the package: %s"%pkgname)

        # Check wether the url or the source exist and if so check wether they are http:// and tar.gz
        if(url != None):
            # Check wether the url start with http://
            if not url.startswith('http://'):
                sys.exit("\nYour URL does not start with 'http://' => %s \n" % url)

            # Check wether the url refers to a .tar.gz
            if not url.startswith('http://') and not url.endswith('.tar.gz'):
                sys.exit("Your URL does not link to a tarball file %s \n" % url)

        if(source != None):
            if not source.endswith('.tar.gz') and not source.endswith('.zip'):    
                sys.exit("Your source is not a tarball (*.tar.gz) or a zip file (*.zip) %s \n" % source )
            if not os.path.exists(source):
                sys.exit("Your source does not exist, please use the full path (%s)"%source)

        # Set the url or source (tarball)
        package.setSource(url, source)
        # Retrieve the package
        package.download()
        # Get the information regarding the packager
        package.setPackager(name, email)
        # Set the name of the package
        package.setName()
        # If it is a package from one of the standard repository, set the URL
        if url is not None: package.setUrl(url)
        if forge: package.setOctForgeURL()
        # Open the package into a tmp directory
        package.openSource()
        # Set the meta information of the spec (license, version, summary, description...)
        package.setDescription()
        # Set the arch (noarch vs *86)
        package.getArch()
        # Remove the tmp directory in which the sources have been extracted
        package.closeSource()
        # Set the date to be used at the bottom of the changelog
        package.setDate()
        print "*"*50,"\n** Generate the spec file"
        package.writeSpec(force, self.todo)
        package.moveSource(copyFile)
        self.package = package
        
        return "octave-" + package.name

#if __name__ == "__main__":
    # Retrieve the given arguments
    #oct2spec().main(None, None, 'ABarray')
